@@ -6,13 +6,15 @@ use std::path::{Path, PathBuf};
 use std::sync::{Arc, LazyLock};
 
 use builtin::{BUILTIN_COMMAND, BUILTIN_MODULE, BUILTIN_VARIABLE};
+use dashmap::DashMap;
 use tokio::sync::Mutex;
 use tower_lsp::lsp_types::{
     CompletionItem, CompletionItemKind, CompletionResponse, Documentation, MessageType, Position,
+    Uri,
 };
 
 use crate::consts::TREESITTER_CMAKE_LANGUAGE;
-use crate::languageserver::get_or_update_buffer_context;
+use crate::languageserver::get_or_update_buffer_contents;
 use crate::scansubs::TREE_MAP;
 use crate::utils::treehelper::{PositionType, ToPoint, get_pos_type};
 use crate::utils::{
@@ -91,7 +93,10 @@ pub async fn update_cache<P: AsRef<Path>>(path: P, context: &str) -> Vec<Complet
     result_data
 }
 
-pub async fn get_cached_completion<P: AsRef<Path>>(path: P) -> Vec<CompletionItem> {
+pub async fn get_cached_completion<P: AsRef<Path>>(
+    path: P,
+    documents: &DashMap<Uri, String>,
+) -> Vec<CompletionItem> {
     let mut path = path.as_ref().to_path_buf();
     let mut completions = Vec::new();
 
@@ -101,7 +106,7 @@ pub async fn get_cached_completion<P: AsRef<Path>>(path: P) -> Vec<CompletionIte
         let complete_cache = COMPLETE_CACHE.lock().await;
         if let Some(data) = complete_cache.get(parent) {
             completions.append(&mut data.clone());
-        } else if let Ok(context) = get_or_update_buffer_context(parent).await {
+        } else if let Ok(context) = get_or_update_buffer_contents(parent, documents).await {
             drop(complete_cache);
             completions.append(&mut update_cache(parent, context.as_str()).await);
             path.clone_from(parent);
@@ -120,6 +125,7 @@ pub async fn getcomplete<P: AsRef<Path>>(
     client: &tower_lsp::Client,
     local_path: P,
     find_cmake_in_package: bool,
+    documents: &DashMap<Uri, String>,
 ) -> Option<CompletionResponse> {
     let local_path = local_path.as_ref();
     let mut parse = tree_sitter::Parser::new();
@@ -131,10 +137,13 @@ pub async fn getcomplete<P: AsRef<Path>>(
     let current_point = location.to_point();
     let postype = get_pos_type(current_point, tree.root_node(), source);
     match postype {
-        PositionType::VarOrFun | PositionType::TargetLink | PositionType::TargetInclude => {
-            let mut cached_compeletion = get_cached_completion(local_path).await;
-            if !cached_compeletion.is_empty() {
-                complete.append(&mut cached_compeletion);
+        PositionType::VarOrFun
+        | PositionType::TargetLink
+        | PositionType::TargetInclude
+        | PositionType::ArgumentOrList => {
+            let mut cached_completion = get_cached_completion(local_path, documents).await;
+            if !cached_completion.is_empty() {
+                complete.append(&mut cached_completion);
             }
             if let Some(mut cmake_cache) = fileapi::get_complete_data() {
                 complete.append(&mut cmake_cache);
@@ -153,7 +162,9 @@ pub async fn getcomplete<P: AsRef<Path>>(
                 complete.append(&mut message);
             }
 
-            if let Ok(messages) = &*BUILTIN_COMMAND {
+            if let Ok(messages) = &*BUILTIN_COMMAND
+                && !matches!(postype, PositionType::ArgumentOrList)
+            {
                 complete.append(&mut messages.clone());
             }
             if let Ok(messages) = &*BUILTIN_VARIABLE {
@@ -171,9 +182,9 @@ pub async fn getcomplete<P: AsRef<Path>>(
             complete.append(&mut findpackage::PKGCONFIG_SOURCE.clone());
         }
         PositionType::Include => {
-            let mut cached_compeletion = get_cached_completion(local_path).await;
-            if !cached_compeletion.is_empty() {
-                complete.append(&mut cached_compeletion);
+            let mut cached_completion = get_cached_completion(local_path, documents).await;
+            if !cached_completion.is_empty() {
+                complete.append(&mut cached_completion);
             }
             if let Some(mut cmake_cache) = fileapi::get_complete_data() {
                 complete.append(&mut cmake_cache);
@@ -197,7 +208,7 @@ pub async fn getcomplete<P: AsRef<Path>>(
     }
 }
 
-/// NOTE: postype can only be VarOrFun | TargetLink | TargetInclude
+/// NOTE: postype can only be VarOrFun | TargetLink | TargetInclude | ArgumentOrList
 /// get the variable from the loop
 /// use position to make only can complete which has show before
 #[allow(clippy::too_many_arguments)]
@@ -214,13 +225,16 @@ fn getsubcomplete<P: AsRef<Path>>(
 ) -> Option<Vec<CompletionItem>> {
     assert!(matches!(
         postype,
-        PositionType::VarOrFun | PositionType::TargetLink | PositionType::TargetInclude
+        PositionType::VarOrFun
+            | PositionType::TargetLink
+            | PositionType::TargetInclude
+            | PositionType::ArgumentOrList
     ));
     let local_path = local_path.as_ref();
-    if let Some(location) = location {
-        if input.start_position().row as u32 > location.line {
-            return None;
-        }
+    if let Some(location) = location
+        && input.start_position().row as u32 > location.line
+    {
+        return None;
     }
 
     let mut course = input.walk();
@@ -230,11 +244,11 @@ fn getsubcomplete<P: AsRef<Path>>(
         comments: vec![],
     };
     for child in input.children(&mut course) {
-        if let Some(location) = location {
-            if child.start_position().row as u32 > location.line {
-                // if this child is below row, then break all loop
-                break;
-            }
+        if let Some(location) = location
+            && child.start_position().row as u32 > location.line
+        {
+            // if this child is below row, then break all loop
+            break;
         }
         match child.kind() {
             CMakeNodeKinds::LINE_COMMENT => {
@@ -469,7 +483,8 @@ fn getsubcomplete<P: AsRef<Path>>(
                                 let mut support_component = false;
                                 let mut components_packages = Vec::new();
                                 for index in 1..argument_count {
-                                    let package_prefix_node = argumentlist.child(index).unwrap();
+                                    let package_prefix_node =
+                                        argumentlist.child(index as u32).unwrap();
                                     let h = package_prefix_node.start_position().row;
                                     let x = package_prefix_node.start_position().column;
                                     let y = package_prefix_node.end_position().column;
@@ -875,7 +890,7 @@ Example using both :command:`configure_package_config_file` and
    check_required_components(Foo)
 #]=======================================================================]
         "#;
-    assert_eq!(rst_doc_read(doc, "FileExample.cmake").len(), 2)
+    assert_eq!(rst_doc_read(doc, "FileExample.cmake").len(), 2);
 }
 
 #[test]
