@@ -1,40 +1,47 @@
-#[cfg(any(
-    target_os = "linux",
-    target_os = "android",
-    target_os = "freebsd",
-    target_os = "openbsd"
-))]
+#[cfg(not(target_os = "windows"))]
 mod packageunix;
-mod vcpkg;
-#[cfg(any(
-    target_os = "linux",
-    target_os = "android",
-    target_os = "freebsd",
-    target_os = "openbsd"
-))]
-use packageunix as cmakepackage;
 #[cfg(target_os = "windows")]
 mod packagewin;
-#[cfg(target_os = "windows")]
-use packagewin as cmakepackage;
+mod vcpkg;
 
-#[cfg(target_os = "macos")]
-mod packagemac;
+use std::borrow::Cow;
 use std::collections::HashMap;
 use std::path::{Path, PathBuf};
 use std::process::Command;
 use std::sync::LazyLock;
 
 pub use cmakepackage::*;
-#[cfg(target_os = "macos")]
-use packagemac as cmakepackage;
 use tower_lsp::lsp_types::Uri;
-pub use vcpkg::*;
+use tree_sitter::Point;
 
-use super::{CMakePackage, CMakePackageFrom, PackageType, remove_quotation};
+#[cfg(not(target_os = "windows"))]
+use self::packageunix as cmakepackage;
+#[cfg(target_os = "windows")]
+use self::packagewin as cmakepackage;
+pub use self::vcpkg::*;
+use super::{CMakePackage, CMakePackageFrom, PackageType};
 use crate::CMakeNodeKinds;
 use crate::consts::TREESITTER_CMAKE_LANGUAGE;
 
+const LIBS: &[Cow<'_, str>] = &[
+    Cow::Borrowed("lib"),
+    Cow::Borrowed("lib32"),
+    Cow::Borrowed("lib64"),
+    Cow::Borrowed("share"),
+];
+
+/// Used to query system information like platform specific paths.
+static CMAKE_SYSTEM_INFORMATION: LazyLock<Option<String>> = LazyLock::new(|| {
+    let output = Command::new("cmake")
+        .arg("--system-information")
+        .output()
+        .ok()?;
+    if !output.status.success() {
+        return None;
+    }
+    String::from_utf8(output.stdout).ok()
+});
+
 fn handle_config_package(filename: &str) -> Option<&str> {
     if let Some(tryfirst) = filename.strip_suffix("-config.cmake") {
         return Some(tryfirst);
@@ -92,16 +99,13 @@ fn query_cmake_prefixes_or(default: Vec<String>) -> Vec<String> {
 }
 
 fn query_cmake_prefixes() -> Option<Vec<String>> {
-    let command = Command::new("cmake")
-        .arg("--system-information")
-        .output()
-        .ok()?;
-    let output = String::from_utf8_lossy(&command.stdout);
-    let line = output
-        .lines()
-        .find(|line| line.starts_with("CMAKE_SYSTEM_PREFIX_PATH"))?;
+    let line = CMAKE_SYSTEM_INFORMATION.as_ref().and_then(|output| {
+        output
+            .lines()
+            .find(|line| line.starts_with("CMAKE_SYSTEM_PREFIX_PATH"))
+    })?;
     let (_, prefix_paths) = line.split_once(" ")?;
-    let prefix_paths = remove_quotation(prefix_paths);
+    let prefix_paths = prefix_paths.trim_matches('"');
     // FIXME: This likely contains duplicate entries of '/usr/local' on most systems
     // This could be solved by using Itertools::unique()
     let prefix_paths: Vec<String> = prefix_paths.split(";").map(String::from).collect();
@@ -113,12 +117,30 @@ fn query_cmake_prefixes() -> Option<Vec<String>> {
     }
 }
 
+/// Returns the value of `CMAKE_LIBRARY_ARCHITECTURE` reported by `cmake --system-information`, if
+/// it's set.
+fn get_library_architecture() -> Option<String> {
+    CMAKE_SYSTEM_INFORMATION
+        .as_ref()
+        .and_then(|output| {
+            output
+                .lines()
+                .find(|line| line.starts_with("CMAKE_LIBRARY_ARCHITECTURE"))
+        })
+        .and_then(|line| line.split_whitespace().nth(1))
+        .map(|line| line.trim_matches('"'))
+        .map(str::to_owned)
+}
+
 fn get_available_libs(prefixes: &[String]) -> Vec<PathBuf> {
+    let lib_arch = get_library_architecture().map(|arch| Cow::Owned(format!("lib/{arch}")));
     prefixes
         .iter()
-        .flat_map(|prefix| {
-            LIBS.into_iter()
-                .map(|lib| Path::new(prefix).join(lib).join("cmake"))
+        .map(Path::new)
+        .flat_map(|path| {
+            LIBS.iter()
+                .chain(lib_arch.iter())
+                .map(|lib| path.join(lib.as_ref()).join("cmake"))
                 .filter(|path| path.exists())
         })
         .collect()
@@ -164,7 +186,7 @@ fn special_package_pattern_tst() {
     assert!(!SPECIAL_PACKAGE_PATTERN.is_match(unmatched_pattern));
 
     let unmatched_pattern = "QuaZip-Qt5";
-    assert!(!SPECIAL_PACKAGE_PATTERN.is_match(unmatched_pattern))
+    assert!(!SPECIAL_PACKAGE_PATTERN.is_match(unmatched_pattern));
 }
 
 // match file xx.cmake and CMakeLists.txt
@@ -271,6 +293,22 @@ pub static CACHE_CMAKE_PACKAGES: LazyLock<Vec<CMakePackage>> = LazyLock::new(get
 pub static CACHE_CMAKE_PACKAGES_WITHKEYS: LazyLock<HashMap<String, CMakePackage>> =
     LazyLock::new(get_cmake_packages_withkeys);
 
+fn string_from_two_valid_points(source: Vec<&str>, start: &Point, end: &Point) -> String {
+    if start.row == end.row {
+        return source[start.row][start.column..end.column].into();
+    }
+
+    let mut span = String::new();
+
+    span += &source[start.row][start.column..];
+    for row in source.iter().take(end.row).skip(start.row + 1) {
+        span += row;
+    }
+    span += &source[end.row][..end.column];
+
+    span
+}
+
 fn get_version(source: &str) -> Option<String> {
     let newsource: Vec<&str> = source.lines().collect();
     let mut parse = tree_sitter::Parser::new();
@@ -296,11 +334,16 @@ fn get_version(source: &str) -> Option<String> {
                 if x != y {
                     let name = &newsource[h][x..y];
                     if name == "PACKAGE_VERSION" {
-                        let h = version.start_position().row;
-                        let x = version.start_position().column;
-                        let y = version.end_position().column;
-                        let version = &newsource[h][x..y];
-                        return Some(remove_quotation(version).to_string());
+                        let version_string = string_from_two_valid_points(
+                            newsource,
+                            &version.start_position(),
+                            &version.end_position(),
+                        );
+                        return Some(
+                            version_string
+                                .trim_matches(|c| c == '"' || c == '\n' || c == ' ')
+                                .to_string(),
+                        );
                     }
                 }
             }
@@ -402,6 +445,13 @@ fn tst_version() {
     assert_eq!(get_version(projectversion), Some("5.11".to_string()));
     let projectversion = "SET(PACKAGE_VERSION 5.11)";
     assert_eq!(get_version(projectversion), Some("5.11".to_string()));
+    let projectversion = "set(PACKAGE_VERSION \"1.3.14
+\")";
+    assert_eq!(get_version(projectversion), Some("1.3.14".to_string()));
+    let projectversion = "set(PACKAGE_VERSION \"1.3.14
+
+\")";
+    assert_eq!(get_version(projectversion), Some("1.3.14".to_string()));
     let qmlversion = include_str!("../../assets_for_test/Qt5QmlConfigVersion.cmake");
     assert_eq!(get_version(qmlversion), Some("5.15.6".to_string()));
 }
